[![PyPI Version](https://img.shields.io/pypi/v/qlet.svg)](https://pypi.org/project/qlet/)
![Python 3.10](https://img.shields.io/badge/python->=3.10-blue.svg)
[![license](https://img.shields.io/github/license/Jarvis-Yu/qlet)](https://github.com/Jarvis-Yu/qlet/blob/master/LICENSE)

# qlet

This is an extension package based on `flet`, which provides a variety of `layouts`
that can auto-resize based on their `ref_parent`.

## Installation

```sh
pip install qlet
```

## Examples

***WIP***

The repo owner is busy recently, but this section should be filled by the end of Feb 2024.
